pub struct Transaction {
pub id: Uuid,
pub post_date: DateTime<Utc>,
pub enter_date: DateTime<Utc>,
}Expand description
The Transaction which is a start point of all the accounting.
A Transaction keeps id of a financial event and is used to group Splits
using all the features provided.
Attributes
id: A unique identifier for the transaction.commodity: A reference to theCommodityassociated of this transaction.num: An optional number or code associated with the transaction.post_date: The date the transaction is performed.enter_date: The date the transaction is entered.description: An optional description of the transaction.
Fields
id: Uuidpost_date: DateTime<Utc>enter_date: DateTime<Utc>Implementations
Sourceimpl Transaction
impl Transaction
pub fn builder() -> TransactionBuilder
Sourceimpl<'t> Transaction
impl<'t> Transaction
Sourcepub async fn enter<'p, E>(
&'t self,
conn: &'p mut E,
) -> Result<TransactionTicket<'t, 'p>, FinanceError>where
E: Connection<Database = Postgres>,
pub async fn enter<'p, E>(
&'t self,
conn: &'p mut E,
) -> Result<TransactionTicket<'t, 'p>, FinanceError>where
E: Connection<Database = Postgres>,
Inserts the transaction into the database and starts data input.
This method begins a new database transaction, inserts the transaction
details into the DB, and returns a TransactionTicket to manage the
rest of data (Splits, Tags, and so on). The DB transaction must be
committed (or rolled back) from via the TransactionTicket returned.
Parameters
conn: A connection to the database.
Returns
A TransactionTicket for managing the transaction.
Errors
Returns a FinanceError if the database operation fails.